
// using Noritake GU140x32F-7000 Display
// JB 8/5/13 //587


#include <device.h>                            // Setup psoc hardware
#include <stdio.h>                             // library for snprintf

                                         // Global variables
float   SPS_Rate = 120;                        // Number of samples per second ADC has been set too, passed to Display, Range ADC lowest setting to 999 (The display is limited to three places for this variable)
float   avgtotake = 9;                         // Number of averages to take, passed to ADC function, range 1 to 99 (The display is limited to three places for this variable, as the results can be floating point)
int     adcResult = 0;                         // adc results count
int     avgadcResult = 0;                      // average adc results count
double  ADC_Volts = 0;                         // ADC_Volts results
double  avgADC_Volts = 0;                      // average of ADC_Volts

                                        // Sets up functions to call
     void initialize(void);                    // initialize has no variables to initialize
     void ADC(void);                           // ADC needs variables to pass to and from it's call and return, needed on entry are number of avgtotake, on return, avgadcResult and avgADC_Volts
     void Display(float avgtotake);            // Display needs variables to pass to it, needed on entry are SPS_Rate, avg to take, avgadcResult and avgADC_Volts

void main()                             // Program flow control loop
{
initialize();                                  // initialize UART, ADC and DISPLAY
    for(;;){                                   // Loop forever, calling ADC then Display
ADC();                                         // Takes readings, averages results and converts count to microvolts 
Display(9);                                    // Formats results and passes them out to display, with handshaking
    }                                          // Loop again
} //end main
                                            
    
   void initialize()
{
 UART_1_Start();		                       // initialize UART
 UART_1_PutChar(0x1b); UART_1_PutChar(0x40);   // initialize VFD
 UART_1_PutChar(0x0c);                         // ClearDisplay
 UART_1_PutChar(0x1f); UART_1_PutChar(0x58);   // Command VFD Brightness level
 UART_1_PutChar(0x01);                         // Set brightness level, 1=12.5%, 2=25%, 3=37.5%, 4=50%, 5=62.5%, 6=75%, 7=87.5%, 8=100%
 ADC_DelSig_1_Start();				           // start the ADC_DelSig_1
 ADC_DelSig_1_StartConvert();		           // start the ADC_DelSig_1 conversion
return; // Return to caller
}       // end initialize


void ADC(void)
{
                                        // Local variables
int avgcount = 0;                                    // loop counter for average

    avgadcResult=0;                                  // clear average for new adc count average
    avgADC_Volts=0;                                  // clear average for new volts average

        for (avgcount=0; avgcount < avgtotake; avgcount++){  // loop for average results
            if (ADC_DelSig_1_IsEndConversion(ADC_DelSig_1_WAIT_FOR_RESULT)){  // function to wait for adc to be ready
            }
        adcResult = ADC_DelSig_1_GetResult32();		 // read the adc and assign the value adcResult 
        adcResult=adcResult-675;
        if (adcResult<0){adcResult=0;}
        ADC_Volts = adcResult*0.00000195897;         // convert count to microvolts
        avgadcResult+=adcResult;                     // add up adc count as many times as average loop is set for
        avgADC_Volts+=ADC_Volts;                     // add up volts as many times as average loop is set for
        }

            avgadcResult=avgadcResult/(avgtotake);   // divide results by average count 
            avgADC_Volts=avgADC_Volts/(avgtotake);   // divide results by average count 

return; // Return to caller
}       // end ADC


void Display(float avgtotake)           // **** Displays results ****
{
char DisCharStr [21]="";                             // length of temp string to hold formatted results for display (set to one line of text)
int  BSCount = 1;                                    // keeps track of how many back spaces have been sent to display

                                        // Output line one
    snprintf (DisCharStr, 21, "ADC:%07d:%1.5fV", adcResult, ADC_Volts);             // Format results for display (max 20 Char)
    UART_1_PutString(DisCharStr);                                                   // Display results (one line, 20 Chars long max)

                                        // Output line two
      snprintf (DisCharStr, 21, "average:%2.0fR @ %3.0fSps",avgtotake,SPS_Rate);    // Format results for display (max 20 Char)
      UART_1_PutString(DisCharStr);                                                 // Display results (one line, 20 Chars long max)

                                        // Output line three
          snprintf (DisCharStr, 21, "ADC:%07d:%1.5fV", avgadcResult, avgADC_Volts); // Format results for display (max 20 Char)
          UART_1_PutString(DisCharStr);                                             // Display results (one line, 20 Chars long max)

                                        // Output line four
            snprintf (DisCharStr, 21, "Display Rate %03.1fRps",SPS_Rate/avgtotake); // Format results for display (max 20 Char)
            UART_1_PutString(DisCharStr);                                           // Display results (one line, 20 Chars long max)

                                        // Home display loop
                for (BSCount=1; BSCount <= 80; BSCount++){ UART_1_PutChar(0x08);    // backspace display to home, results are over written so dislay does not flicker
            }
return; // Return to caller
}       // end Display


/* [] END OF FILE */